/*
   FILNAME:		   sheetWithTab.cpp

   PURPOSE:   

   CREATED BY:    Per Ghosh
   ENVIRONMENT:	Visual C++ 4.0


INFO:
*/

#include "stdafx.h"
#include "resource.h"
#include "sheetWithTab.h"

#ifdef _DEBUG
#undef THIS_FILE
static char BASED_CODE THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CsheetWithTab

IMPLEMENT_DYNAMIC(CsheetWithTab, CPropertySheet)

/************************************************
   *   Constructor/Destructor 
   *
 * * *
  ***
   *
*/
CsheetWithTab::CsheetWithTab(CWnd* pWndParent)
	 : CPropertySheet(IDS_PROPSHT_CAPTION, pWndParent), m_bNoTabs(FALSE), m_iDistanceFromTop(0)
{
	AddPage(&m_Page1);
	AddPage(&m_Page2);
}


CsheetWithTab::CsheetWithTab(CRect& rect, CWnd* pWndParent)
	 : CPropertySheet(IDS_PROPSHT_CAPTION, pWndParent), m_bNoTabs(FALSE), m_iDistanceFromTop(0)
{
   m_Rect = rect;
	AddPage(&m_Page1);
	AddPage(&m_Page2);
}

CsheetWithTab::~CsheetWithTab()
{
}

/************************************************
   *   Virtual functions
   *
 * * *
  ***
   *
*/

static int module_piButtons[] = { IDOK, IDCANCEL, ID_APPLY_NOW, IDHELP };

/*-------------------------------------------------------------------------------------------------
Name:	   OnInitDialog()
Type:    virtual
Purpose: called by framework when WM_INITDIALOG is sent, modify size for the propertysheet here

Return:  BOOL

Info:
When the position and size for a propertysheet is to be set, we have to override OnInitDialog and
do not call the default OnInitDialog !!!. The solution MFC has done for implementing Propertysheets 
is a little strange I think. 
It might be other ways to set size and position for Propertysheets. 
Test an see !
*/
BOOL CsheetWithTab::OnInitDialog() 
{
   HWND hTabWnd;
   CRect rectTabCtrl;

   if( m_Rect.right )
   {
	   // resize the tab control
	   hTabWnd = (HWND)::GetDlgItem(m_hWnd, AFX_IDC_TAB_CONTROL);
	   ASSERT(hTabWnd != NULL);
	   ::GetWindowRect(hTabWnd, &rectTabCtrl);  // Tab-control rectangle (screen coordinates)
	   ScreenToClient(rectTabCtrl);

      // Is tab-control wider than specified width.
      if( rectTabCtrl.right > (m_Rect.Width() - 3) )
      {
         rectTabCtrl.right = m_Rect.Width() - 3; // Set new right position
      }

      // The tab-control does only need to show tabs
      rectTabCtrl.bottom = 32;                 // Height for tabs

      // move tab control
      ::MoveWindow( hTabWnd, 0, m_iDistanceFromTop, rectTabCtrl.Width(), rectTabCtrl.bottom, TRUE );

	   BOOL bResult = (BOOL)Default();          // Process messages

      // If propertysheet m_bNoTabs = TRUE hide the tabs
      if( m_bNoTabs )
      {
         ::ShowWindow(hTabWnd, SW_HIDE);
         ::EnableWindow(hTabWnd, FALSE);
      }
   
	   // change tab style if scrolling tabs desired (stacked tabs are default)
	   if (!m_bStacked)
	   {
		   hTabWnd = (HWND)SendMessage(PSM_GETTABCONTROL);
		   if (hTabWnd != NULL)
         {
			   CWnd::ModifyStyle(hTabWnd, TCS_MULTILINE, TCS_SINGLELINE, 0);
         }
	   }

      // remove standard buttons 
	   for (int i = 0; i < 4; i++)
	   {
		   HWND hWnd = ::GetDlgItem(m_hWnd, module_piButtons[i]);
		   if (hWnd != NULL)
		   {
			   ::ShowWindow(hWnd, SW_HIDE);
			   ::EnableWindow(hWnd, FALSE);
		   }
	   }

      // Move the propertysheet to specified position
      MoveWindow( m_Rect.left, m_Rect.top, m_Rect.right, m_Rect.bottom /*- cyDiff*/ );

      return bResult;
   }

   return CPropertySheet::OnInitDialog();
}

/************************************************
   *   Functions 
   *
 * * *
  ***
   *
*/



BEGIN_MESSAGE_MAP(CsheetWithTab, CPropertySheet)
	//{{AFX_MSG_MAP(CsheetWithTab)
	ON_WM_CTLCOLOR_REFLECT()
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/************************************************
   *   Messages
   *
 * * *
  ***
   *
*/

/*-------------------------------------------------------------------------------------------------
Name:	   CtlColor
Type:    message
Purpose: Change color for propertysheet here

Param:   pDC = point to dc for propertysheet
         nCtlColor = type of control

Return:  HBRUSH, Color that propertysheet are going to have, NULL if no change.
*/
HBRUSH CsheetWithTab::CtlColor(CDC* pDc, UINT uCtlColor) 
{
   CWnd*    pwndParent;   // Parent window to property-sheet
   CDC*     pdcParent;    // Parent dc
   COLORREF color;        // color on parent dc           

   pwndParent = GetParent();
   ASSERT( pwndParent->IsKindOf( RUNTIME_CLASS( CWnd ) ) ); 

   pdcParent = pwndParent->GetDC();

   color = pdcParent->GetBkColor();    // Get parent color

   pwndParent->ReleaseDC( pdcParent );

   CBrush brush( color );              // Make a brush
	
	return (HBRUSH)brush;
}
